Welcome to CulebrONT's documentation!
=====================================


.. image:: _images/culebront_logo.png
   :target: _images/culebront_logo.png
   :align: center
   :alt: Culebront Logo

Today, assembling a genome using long reads from Oxford Nanopore Technologies is really interesting in particular to solve repeats and structural variants in prokaryotic as well as in eukaryotic genomes. Assemblies are increasing in contiguity and accuracy.

The daily increase of data sequences obtained and the fact that more and more tools are being released or updated every week,
many species are having their genomes assembled and that’s is great ...

"\ *But which assembly tool could give the best results for your favorite organism?*\ "

**CulebrONT can help you!** CulebrONT is an open-source, scalable, modular and traceable Snakemake pipeline, able to launch multiple assembly tools in parallel, giving you the possibility of circularise, polish, and correct assemblies, checking quality. CulebrONT can help to choose the best assembly between all possibilities.

.. toctree::
   :caption: About CulebrONT
   :name: about_culebront
   :maxdepth: 2

   ABOUT.rst

.. toctree::
   :caption: Install
   :name: install
   :maxdepth: 2

   INSTALL.rst

.. toctree::
   :caption: Defining Workflows
   :name: defining_workflows
   :maxdepth: 2

   WORKFLOWS.rst

.. toctree::
   :caption: Project Info
   :name: project_info
   :maxdepth: 1

   PROJECT.rst

.. toctree::
   :caption: FAQ
   :name: faq_questions
   :maxdepth: 2

   FAQ.rst

.. toctree::
   :caption: API
   :name: api_culebront
   :maxdepth: 2

   click.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
